"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helper_plugin_utils_1 = require("@babel/helper-plugin-utils");
function preset(api, presetOption) {
    api.assertVersion(7);
    var react = typeof presetOption.react === 'undefined' ? true : presetOption.react;
    var typescript = typeof presetOption.typescript === 'undefined' ? true : presetOption.typescript;
    var classProperties = presetOption['class-properties'] || {};
    var decorators = presetOption.decorators || {
        decoratorsBeforeExport: true,
    };
    var throwIfNamespace = typeof presetOption['throw-if-namespace'] === 'undefined' ? false : presetOption['throw-if-namespace'];
    var targets = typeof presetOption.target === 'undefined'
        ? ['chrome >= 49', 'firefox >= 64', 'ios >= 8', 'Android > 4.4']
        : presetOption.target;
    var presets = [[require.resolve('@babel/preset-env'), { targets: targets }]];
    if (typescript) {
        presets.push([require.resolve('@babel/preset-typescript'), typeof typescript === 'object' ? typescript : {}]);
    }
    if (react) {
        var defaultReactOpt = { throwIfNamespace: throwIfNamespace };
        var reactOpts = typeof react === 'boolean' ? defaultReactOpt : Object.assign(defaultReactOpt, react);
        presets.push([require.resolve('@babel/preset-react'), reactOpts]);
    }
    return {
        presets: presets,
        plugins: [
            require.resolve('babel-plugin-macros'),
            require.resolve('@babel/plugin-proposal-object-rest-spread'),
            require.resolve('@babel/plugin-proposal-optional-chaining'),
            require.resolve('@babel/plugin-proposal-nullish-coalescing-operator'),
            [require.resolve('@babel/plugin-syntax-jsx'), { throwIfNamespace: throwIfNamespace }],
            [require.resolve('@babel/plugin-proposal-decorators'), decorators],
            [require.resolve('@babel/plugin-proposal-class-properties'), classProperties],
            [
                require.resolve('babel-plugin-auto-import'),
                {
                    declarations: [{ default: 'regeneratorRuntime', path: 'regenerator-runtime' }],
                },
            ],
            require.resolve('@ray-core/babel-plugin-auto-css-modules'),
        ],
    };
}
exports.default = (0, helper_plugin_utils_1.declare)(preset);
